==============================
Reference documentation
==============================

.. currentmodule:: pyxnat.core


The `Interface` class
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.Interface
    :members:
    :inherited-members:


The `Select` class
~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.select.Select
    :members: __call__, project, projects

The `Inspect` class
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.help.Inspector
    :members:

The `SearchManager` class
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.search.SearchManager
    :members:

The `Search` class
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.search.Search
    :members:

The `EObject` class
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.resources.EObject
    :members:

The `CObject` class
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.resources.CObject
    :members:

The `Project` class
~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.resources.Project
    :members:

The `File` class
~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.resources.File
    :members:

The `Attributes` class
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.attributes.EAttrs
    :members:

The `Provenance` class
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.provenance.Provenance
    :members:

The `Users` class
~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.users.Users
    :members:

The `Inspector` class
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.help.Inspector
    :members:

The `CacheManager` class
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.cache.CacheManager
    :members:

The `SchemaManager` class
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: pyxnat.core.manage.SchemaManager
    :members:

